==> haskell-profunctors-5.2-8-armv7h.pkg.tar.xz: usr/share/haskell/haskell-profunctors/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2
id: profunctors-5.2-dcebd670a79351324a9f8d71a72c88e3
key: profu_EsFQssGKUvQ2ZN47Ban4iz
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/profunctors-5.2
hs-libraries: HSprofunctors-5.2-EsFQssGKUvQ2ZN47Ban4iz
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
    bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
    comonad-5-a91321d086a2de4a04a44d60c347669e
    contravariant-1.4-7b1149a75def92c79deb23a86e0b36cb
    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.2-9-armv7h.pkg.tar.xz: usr/share/haskell/haskell-profunctors/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2
id: profunctors-5.2-aaf86384a4db0133740cbda80ff5e59a
key: profu_2wAzSKoUTy2128FFgbcrKX
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/profunctors-5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/profunctors-5.2
hs-libraries: HSprofunctors-5.2-2wAzSKoUTy2128FFgbcrKX
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base-orphans-0.5.3-27215a9428d23686c8514fbd3bba8ccb
    bifunctors-5.2.1-3dea194c07c9b02982b78a82398333cc
    comonad-5-e98e7adc8875accf64a86529d9aeae51
    contravariant-1.4-6e8bc7cb2457226c1a88750295477d07
    distributive-0.5.0.2-6c580c91b8bf5de803bfa850eb262f37
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
